@@ -5,15 +5,15 @@ import time
 from argparse import ArgumentParser
 import pkg_resources
 from subprocess import check_call
-
-from pyshortcuts import make_shortcut, ico_ext
+import shutil
+from pyshortcuts import make_shortcut, ico_ext, get_desktop
 
 from .site_config import icondir, home_dir, uname
 from .site_config import (extras_wxgraph, extras_qtgraph,
                           extras_epics, extras_xrd, extras_doc)
 from .shell import shell
 from .xmlrpc_server import larch_server_cli
-from .version import __version__, __date__, make_banner, check_larchversion
+from .version import __date__, make_banner, check_larchversion
 
 HAS_CONDA = os.path.exists(os.path.join(sys.prefix, 'conda-meta'))
 
@@ -118,7 +118,7 @@ class LarchApp:
 APPS = (LarchApp('Larch CLI', 'larch', terminal=True),
         LarchApp('Larch GUI', 'larch --wxgui'),
         LarchApp('XAS Viewer',  'xas_viewer',  icon='onecone'),
-        LarchApp('GSE MapVewer', 'gse_mapviewer',  icon='gse_xrfmap'),
+        LarchApp('GSE MapViewer', 'gse_mapviewer',  icon='gse_xrfmap'),
         LarchApp('XRF Display',  'xrfdisplay',  icon='ptable'),
         # LarchApp('GSE DTCorrect', 'gse_dtcorrect'),
         # LarchApp('Dioptas', 'dioptas_larch', icon='dioptas'),
@@ -128,7 +128,11 @@ APPS = (LarchApp('Larch CLI', 'larch', terminal=True),
 
 
 def make_desktop_shortcuts():
-    """make desktop shortcuts for Larch apps"""
+    """make desktop shortcuts for Larch apps,
+    first clearing any existing shortcuts"""
+    larchdir = os.path.join(get_desktop(), 'Larch')
+    if os.path.exists(larchdir):
+        shutil.rmtree(larchdir)
     for app in APPS:
         app.create_shortcut()
 
