@@ -134,6 +134,9 @@ class Interpreter:
         for fname, sym in list(builtins.numpy_renames.items()):
             setattr(mathgroup, fname, getattr(numpy, sym))
 
+        for name, value in builtins.constants.items():
+            setattr(mathgroup, name, value)
+
         core_groups = ['_main', '_sys', '_builtin', '_math']
         for groupname, entries in builtins.init_builtins.items():
             if groupname not in core_groups:
@@ -173,7 +176,7 @@ class Interpreter:
 
         if with_plugins: # add all plugins in standard plugins folder
             print("WARNING: Plugins are deprecated and will be removed in 2022")
-            plugins_dir = os.path.join(site_config.usr_larchdir, 'plugins')
+            plugins_dir = os.path.join(site_config.user_larchdir, 'plugins')
             loaded_plugins = []
             for pname in sorted(os.listdir(plugins_dir)):
                 if pname not in loaded_plugins:
@@ -921,8 +924,6 @@ class Interpreter:
             thismod = st_sys.modules[name]
         elif name in sys.modules:
             thismod = sys.modules[name]
-        if name == 'larch':
-            thismod.is_from_python = False
         if thismod is None or do_reload:
             # first look for "name.lar"
             islarch = False
