@@ -1,8 +1,9 @@
 #!/usr/bin/env python
-__date__    = '2021-Jun-12'
-__version__ = '0.9.52'
+__date__    = '2021-Jul-1'
+__release_version__ = '0.9.53'
 __authors__ = "M. Newville, M. Koker, B. Ravel, and others"
 
+
 import sys
 import numpy
 import scipy
@@ -10,6 +11,13 @@ import matplotlib
 import lmfit
 from collections import OrderedDict, namedtuple
 from packaging.version import parse as ver_parse
+from importlib.metadata import version, PackageNotFoundError
+try:
+    __version__ = version("xraylarch")
+except PackageNotFoundError:
+    # package is not installed
+    __version__ = __release_version__
+
 import requests
 from requests.packages.urllib3.exceptions import InsecureRequestWarning
 
@@ -19,7 +27,7 @@ def version_data(mods=None):
         sysvers = sysvers.split('\n')[0]
 
     vdat = OrderedDict()
-    vdat['larch'] = "%s (%s) %s" % (__version__, __date__, __authors__)
+    vdat['larch'] = f'{__release_version__} ({__date__}) {__authors__}'
     vdat['python'] = "%s" % (sysvers)
 
     allmods = [numpy, scipy, matplotlib, lmfit]
@@ -48,6 +56,8 @@ def make_banner(mods=None):
     for name, vstr in vdat.items():
         reqs.append('%s %s' % (name, vstr))
     lines.append(', '.join(reqs))
+    if __version__ != __release_version__:
+        lines.append(f'Devel Version: {__version__:s}')
 
     linelen = max([len(line) for line in lines])
     border = '='*max(linelen, 75)
@@ -77,8 +87,13 @@ from a Command Window or Terminal.
 LATEST_MESSAGE = """Larch version {local_version:s} is up to date."""
 
 def check_larchversion():
+    local_version = __release_version__
+
     requests.packages.urllib3.disable_warnings(InsecureRequestWarning)
-    req = requests.get(VERSION_URL, verify=False, timeout=5)
+    try:
+        req = requests.get(VERSION_URL, verify=False, timeout=3)
+    except:
+        return VersionStatus(False, local_version, 'unknown', 'offline')
     remote_version = '0.9.001'
     if req.status_code == 200:
         try:
@@ -89,7 +104,6 @@ def check_larchversion():
                     break
         except:
             pass
-    local_version = __version__
     update_available = ver_parse(remote_version) > ver_parse(local_version)
     message = UPDATE_MESSAGE if update_available else LATEST_MESSAGE
     message = message.format(remote_version=remote_version,
