@@ -63,6 +63,7 @@ class ParameterWidgets(object):
 
         self.parent = parent
         self.param = param
+        self.widgets = []
         self._saved_expr = ''
         if (prefix is not None and
             not self.param.name.startswith(prefix)):
@@ -73,10 +74,17 @@ class ParameterWidgets(object):
 
         # set vary_choice from param attributes
         vary_choice = PAR_VAR
+        value = None
         if param.expr not in (None, 'None', ''):
             vary_choice = PAR_CON
-        elif not param.vary:
-            vary_choice = PAR_FIX
+            try:
+                value = param.value
+            except:
+                value = -np.Inf
+
+        else:
+            value = param.value
+            vary_choice = PAR_VAR if param.vary else PAR_FIX
 
         if 'name' in widgets:
             name = param.name
@@ -86,15 +94,16 @@ class ParameterWidgets(object):
                 name_size = min(50, len(param.name)*10)
             self.name = wx.StaticText(parent, label=name,
                                       size=(name_size, -1))
-
+            self.widgets.append(self.name)
         if 'value' in widgets:
-            self.value = FloatCtrl(parent, value=param.value,
+            self.value = FloatCtrl(parent, value=value,
                                    minval=param.min,
                                    maxval=param.max,
                                    action=self.onValue,
                                    act_on_losefocus=True,
                                    gformat=True,
                                    size=(float_size, -1))
+            self.widgets.append(self.value)
 
         if 'minval' in widgets:
             minval = param.min
@@ -105,6 +114,7 @@ class ParameterWidgets(object):
                                     size=(minmax_size, -1),
                                     act_on_losefocus=True,
                                     action=self.onMinval)
+            self.widgets.append(self.minval)
             self.minval.Enable(vary_choice==PAR_VAR)
 
         if 'maxval' in widgets:
@@ -116,12 +126,14 @@ class ParameterWidgets(object):
                                     size=(minmax_size, -1),
                                     act_on_losefocus=True,
                                     action=self.onMaxval)
+            self.widgets.append(self.maxval)
             self.maxval.Enable(vary_choice==PAR_VAR)
 
         if 'vary' in widgets:
             self.vary = Choice(parent, size=(90, -1),
                                choices=VARY_CHOICES,
                                action=self.onVaryChoice)
+            self.widgets.append(self.vary)
             self.vary.SetStringSelection(vary_choice)
 
         if 'expr' in widgets:
@@ -130,18 +142,32 @@ class ParameterWidgets(object):
                 expr = ''
             self._saved_expr = expr
             self.expr = wx.TextCtrl(parent, -1, value=expr,
-                                      size=(expr_size, -1))
+                                    size=(expr_size, -1),
+                                    style=wx.TE_PROCESS_ENTER)
+            self.widgets.append(self.expr)
             self.expr.Enable(vary_choice==PAR_CON)
-            self.expr.Bind(wx.EVT_CHAR, self.onExprChar)
-            self.expr.Bind(wx.EVT_KILL_FOCUS, self.onExprKillFocus)
+            self.expr.Bind(wx.EVT_TEXT_ENTER, self.onExpr)
+            self.expr.Bind(wx.EVT_KILL_FOCUS, self.onExpr)
             SetTip(self.expr, 'Enter constraint expression')
 
+            if param.expr not in (None, 'None', ''):
+                try:
+                    ast.parse(param.expr)
+                    bgcol, fgcol = 'white', 'black'
+                except SyntaxError:
+                    bgcol, fgcol = 'white', '#AA0000'
+
+                self.expr.SetForegroundColour(fgcol)
+                self.expr.SetBackgroundColour(bgcol)
+
+
         if 'stderr' in widgets:
             stderr = param.stderr
             if stderr in (None, 'None', ''):
                 stderr = ''
             self.stderr = wx.StaticText(parent, label=stderr,
                                         size=(stderr_size, -1))
+            self.widgets.append(self.expr)
 
         if 'minval' in widgets or 'maxval' in widgets:
             minval = param.min
@@ -157,6 +183,7 @@ class ParameterWidgets(object):
             self.bounds = Choice(parent, size=(90, -1),
                                  choices=BOUNDS_CHOICES,
                                  action=self.onBOUNDSChoice)
+            self.widgets.append(self.bounds)
             self.bounds.SetStringSelection(bounds_choice)
 
     def onBOUNDSChoice(self, evt=None):
@@ -180,16 +207,6 @@ class ParameterWidgets(object):
         if value is not None:
             self.param.value = value
 
-    def onExprChar(self, evt=None):
-        key = evt.GetKeyCode()
-        if key == wx.WXK_RETURN:
-            self.onExpr(value=self.expr.GetValue())
-        evt.Skip()
-
-    def onExprKillFocus(self, evt=None):
-        self.onExpr(value=self.expr.GetValue())
-        evt.Skip()
-
     def onExpr(self, evt=None, value=None):
         if value is None and evt is not None:
             value = evt.GetString()
@@ -198,7 +215,7 @@ class ParameterWidgets(object):
             self.param.expr = value
             bgcol, fgcol = 'white', 'black'
         except SyntaxError:
-            bgcol, fgcol = 'red', 'yellow'
+            bgcol, fgcol = 'white', '#AA0000'
 
         self.expr.SetForegroundColour(fgcol)
         self.expr.SetBackgroundColour(bgcol)
@@ -258,11 +275,11 @@ class ParameterWidgets(object):
         if self.expr is not None:
             self.expr.Enable(vary==PAR_CON)
         if self.minval is not None:
-            self.minval.Enable(vary==PAR_VAR)
+            self.minval.Enable(vary!=PAR_FIX)
         if self.maxval is not None:
-            self.maxval.Enable(vary==PAR_VAR)
+            self.maxval.Enable(vary!=PAR_FIX)
         if self.bounds is not None:
-            self.bounds.Enable(vary==PAR_VAR)
+            self.bounds.Enable(vary!=PAR_FIX)
 
 
 class ParameterDialog(wx.Dialog):
