@@ -4,6 +4,7 @@ Linear Combination panel
 """
 import os
 import time
+import copy
 import wx
 import numpy as np
 
@@ -72,7 +73,7 @@ xftr_cmd = """xftr({group:s}, rmin={fft_rmin: .3f}, rmax={fft_rmax: .3f},
 
 
 defaults = dict(e0=-1.0, rbkg=1, bkg_kmin=0, bkg_kmax=None, bkg_clamplo=0,
-                bkg_clamphi=1, bkg_kweight=1, fft_kmin=2.5, fft_kmax=None,
+                bkg_clamphi=1, bkg_kweight=2, fft_kmin=2.5, fft_kmax=None,
                 fft_dk=4, fft_kweight=2, fft_kwindow='Kaiser-Bessel',
                 fft_rmin=1, fft_rmax=6, fft_dr=0.25,
                 fft_rwindow='Hanning')
@@ -89,6 +90,7 @@ class EXAFSPanel(TaskPanel):
         self.last_plot = 'one'
         self.last_process_bkg = {}
         self.last_process_fft = {}
+        self.last_process_time = time.time() - 5000
 
     def build_display(self):
         panel = self.panel
@@ -129,9 +131,11 @@ class EXAFSPanel(TaskPanel):
         wids['plot_voffset'] = FloatSpin(panel, value=0, digits=2, increment=0.25,
                                          action=self.onProcess)
         wids['plot_kweight'] = FloatSpin(panel, value=2, digits=1, increment=1,
-                                         action=self.onProcess, min_val=0, max_val=5)
+                                         action=self.onProcess,
+                                         min_val=0, max_val=5)
         wids['plot_kweight_alt'] = FloatSpin(panel, value=2, digits=1, increment=1,
-                                             action=self.onProcess,  min_val=0, max_val=5)
+                                             action=self.onProcess,
+                                             min_val=0, max_val=5)
 
         opts = dict(digits=2, increment=0.1, min_val=0, action=self.onProcess)
         wids['e0'] = FloatSpin(panel, **opts)
@@ -156,18 +160,19 @@ class EXAFSPanel(TaskPanel):
         wids['fft_dr'] = FloatSpin(panel, value=0.5,  **opts)
 
         opts.update({'increment': 1, 'digits': 1, 'max_val': 5})
-        wids['bkg_kweight'] = FloatSpin(panel, value=1, **opts)
-        wids['fft_kweight'] = FloatSpin(panel, value=1, **opts)
+        wids['bkg_kweight'] = FloatSpin(panel, value=2, **opts)
+        wids['fft_kweight'] = FloatSpin(panel, value=2, **opts)
 
         opts = dict(choices=CLAMPLIST, size=(80, -1), action=self.onProcess)
         wids['bkg_clamplo'] = Choice(panel, **opts)
         wids['bkg_clamphi'] = Choice(panel, **opts)
 
         wids['fft_kwindow'] = Choice(panel, choices=list(FTWINDOWS),
-                                     action=self.onProcess, size=(150, -1))
+                                     action=self.onProcess, size=(125, -1))
+
 
         wids['fft_rwindow'] = Choice(panel, choices=list(FTWINDOWS),
-                                     action=self.onProcess, size=(150, -1))
+                                     action=self.onProcess, size=(125, -1))
         wids['fft_rwindow'].SetStringSelection('Hanning')
 
 
@@ -216,7 +221,6 @@ class EXAFSPanel(TaskPanel):
         panel.Add((10, 10), dcol=2)
         panel.Add(CopyBtn('e0'), style=RIGHT)
 
-
         add_text('R bkg: ')
         panel.Add(wids['rbkg'])
         panel.Add((10, 10), dcol=2)
@@ -224,7 +228,7 @@ class EXAFSPanel(TaskPanel):
 
         add_text('k min: ')
         panel.Add(bkg_kmin)
-        panel.Add(SimpleText(panel, 'k max:', size=(75, -1)), style=LEFT)
+        panel.Add(SimpleText(panel, 'k max:'), style=LEFT)
         panel.Add(bkg_kmax)
         panel.Add(CopyBtn('bkg_krange'), style=RIGHT)
 
@@ -233,7 +237,6 @@ class EXAFSPanel(TaskPanel):
         panel.Add((10, 10), dcol=2)
         panel.Add(CopyBtn('bkg_kweight'), style=RIGHT)
 
-
         add_text('Clamps Low E: ', newrow=True)
         panel.Add( wids['bkg_clamplo'])
         add_text('high E: ',  newrow=False)
@@ -247,11 +250,9 @@ class EXAFSPanel(TaskPanel):
         panel.Add(SimpleText(panel, 'Copy To Selected Groups:'),
                   style=RIGHT, dcol=3)
 
-
         panel.Add(SimpleText(panel, 'k min: '), newrow=True)
         panel.Add(fft_kmin)
-
-        panel.Add(SimpleText(panel, 'k max:', size=(75, -1)), style=LEFT)
+        panel.Add(SimpleText(panel, 'k max:'), style=LEFT)
         panel.Add(fft_kmax)
         panel.Add(CopyBtn('fft_krange'), style=RIGHT)
 
@@ -260,10 +261,9 @@ class EXAFSPanel(TaskPanel):
         panel.Add((10, 10), dcol=2)
         panel.Add(CopyBtn('fft_kweight'), style=RIGHT)
 
-
-        panel.Add(SimpleText(panel, 'K window : '), newrow=True)
+        panel.Add(SimpleText(panel, 'k window : '), newrow=True)
         panel.Add(wids['fft_kwindow'])
-        panel.Add(SimpleText(panel, ' dk : '))
+        panel.Add(SimpleText(panel, 'dk : '))
         panel.Add(wids['fft_dk'])
         panel.Add(CopyBtn('fft_kwindow'), style=RIGHT)
 
@@ -279,13 +279,13 @@ class EXAFSPanel(TaskPanel):
         panel.Add(SimpleText(panel, 'R min: '), newrow=True)
         panel.Add(fft_rmin)
 
-        panel.Add(SimpleText(panel, 'R max:', size=(75, -1)), style=LEFT)
+        panel.Add(SimpleText(panel, 'R max:'), style=LEFT)
         panel.Add(fft_rmax)
         panel.Add(CopyBtn('fft_rrange'), style=RIGHT)
 
         panel.Add(SimpleText(panel, 'R window : '), newrow=True)
         panel.Add(wids['fft_rwindow'])
-        panel.Add(SimpleText(panel, ' dR : '))
+        panel.Add(SimpleText(panel, 'dR : '))
         panel.Add(wids['fft_dr'])
         panel.Add(CopyBtn('fft_rwindow'), style=RIGHT)
 
@@ -308,45 +308,49 @@ class EXAFSPanel(TaskPanel):
         """get and set processing configuration for a group"""
         if dgroup is None:
             dgroup = self.controller.get_group()
+        if dgroup is None:
+            return self.get_defaultconfig()
 
-        conf = getattr(dgroup, self.configname, self.get_defaultconfig())
+        conf = getattr(dgroup, self.configname, None)
+        if conf is None:
+            # initial reading: start with default then take Athena Project values
+            conf = self.get_defaultconfig()
 
-        bkg_kmax = conf.get('bkg_kmax', None)
-        fft_kmax = conf.get('fft_kmax', None)
-        if None in (bkg_kmax, fft_kmax):
-            e0 = conf.get('e0', -1)
-            emin = min(dgroup.energy)
-            if e0 is None or e0 < emin:
-                e0 = getattr(dgroup, 'e0',  emin)
-            kmax = etok(max(dgroup.energy) - e0)
+            bkg_kmax = conf.get('bkg_kmax', None)
+            fft_kmax = conf.get('fft_kmax', None)
+            if None in (bkg_kmax, fft_kmax):
+                e0 = conf.get('e0', -1)
+                emin = min(dgroup.energy)
+                if e0 is None or e0 < emin:
+                    e0 = getattr(dgroup, 'e0',  emin)
+                kmax = etok(max(dgroup.energy) - e0)
 
-            if bkg_kmax is None or bkg_kmax < 0:
-                conf['bkg_kmax'] = kmax + 0.1
-            if fft_kmax is None or fft_kmax < 0:
-                conf['fft_kmax'] = kmax - 1
+                if bkg_kmax is None or bkg_kmax < 0:
+                    conf['bkg_kmax'] = kmax + 0.1
+                if fft_kmax is None or fft_kmax < 0:
+                    conf['fft_kmax'] = kmax - 1
 
-        if hasattr(dgroup, 'bkg_params'): # from Athena
-            conf['e0'] =  dgroup.bkg_params.e0
-            conf['rbkg'] =  dgroup.bkg_params.rbkg
-            conf['bkg_kmin'] =  dgroup.bkg_params.spl1
-            conf['bkg_kmax'] =  dgroup.bkg_params.spl2
-            conf['bkg_kweight'] =  dgroup.bkg_params.kw
-            conf['bkg_clamplo'] =  dgroup.bkg_params.clamp1
-            conf['bkg_clamphi'] =  dgroup.bkg_params.clamp2
+            if hasattr(dgroup, 'bkg_params'): # from Athena
+                conf['e0'] =  dgroup.bkg_params.e0
+                conf['rbkg'] =  dgroup.bkg_params.rbkg
+                conf['bkg_kmin'] =  dgroup.bkg_params.spl1
+                conf['bkg_kmax'] =  dgroup.bkg_params.spl2
+                conf['bkg_kweight'] =  dgroup.bkg_params.kw
+                conf['bkg_clamplo'] =  dgroup.bkg_params.clamp1
+                conf['bkg_clamphi'] =  dgroup.bkg_params.clamp2
 
-        if hasattr(dgroup, 'fft_params'): # from Athena
-            conf['fft_kmin'] =  2.0
-            conf['fft_kmax'] =  None
-            conf['fft_dk'] =  4.0
-            conf['fft_kwindow'] =  'kaiser-bessel'
-            conf['fft_kweight'] =  2
-            if hasattr(dgroup.fft_params, 'kw'):
-                conf[f'fft_kweight'] = getattr(dgroup.fft_params, 'kw')
-            for attr in ('kmin', 'kmax', 'dk', 'kwindow'):
-                if hasattr(dgroup.fft_params, attr):
-                    conf[f'fft_{attr:s}'] = getattr(dgroup.fft_params, attr)
+            if hasattr(dgroup, 'fft_params'): # from Athena
+                conf['fft_kmin'] =  2.0
+                conf['fft_kmax'] =  None
+                conf['fft_dk'] =  4.0
+                conf['fft_kwindow'] =  'kaiser-bessel'
+                conf['fft_kweight'] =  2
+                if hasattr(dgroup.fft_params, 'kw'):
+                    conf[f'fft_kweight'] = getattr(dgroup.fft_params, 'kw')
+                for attr in ('kmin', 'kmax', 'dk', 'kwindow'):
+                    if hasattr(dgroup.fft_params, attr):
+                        conf[f'fft_{attr:s}'] = getattr(dgroup.fft_params, attr)
 
-        if dgroup is not None:
             setattr(dgroup, self.configname, conf)
         return conf
 
@@ -373,7 +377,11 @@ class EXAFSPanel(TaskPanel):
                 val = opts.get(attr, -1)
                 if val is None:
                     val = '0'
-            wids[attr].SetStringSelection("%d" % opts.get(attr, 0))
+            try:
+                wids[attr].SetStringSelection("%d" % float(opts.get(attr, 0)))
+            except:
+                print(f"could not set '{attr:s}' to {val}")
+
 
         for attr in ('fft_kwindow', 'plotone_op', 'plotsel_op', 'plotalt_op'):
             if attr in opts:
@@ -388,7 +396,7 @@ class EXAFSPanel(TaskPanel):
 
         self.skip_process = False
 
-    def read_form(self, dgroup=None):
+    def read_form(self, dgroup=None, as_copy=False):
         "read form, return dict of values"
         skip_save = self.skip_process
         self.skip_process = True
@@ -396,9 +404,10 @@ class EXAFSPanel(TaskPanel):
         if dgroup is None:
             dgroup = self.controller.get_group()
         self.dgroup = dgroup
-        if dgroup is None:
-            return {}
-        form_opts = {'group': dgroup.groupname}
+
+        conf = self.get_config()
+        if dgroup is not None:
+            conf['group'] = dgroup.groupname
 
         wids = self.wids
         for attr in ('e0', 'rbkg', 'bkg_kmin', 'bkg_kmax',
@@ -407,33 +416,31 @@ class EXAFSPanel(TaskPanel):
                      'fft_rmin', 'fft_rmax', 'fft_dr',
                      'plot_kweight',
                      'plot_kweight_alt', 'plot_voffset'):
-            form_opts[attr] = wids[attr].GetValue()
+            conf[attr] = wids[attr].GetValue()
 
         for attr in ('bkg_clamplo', 'bkg_clamphi'):
-            form_opts[attr] = int(wids[attr].GetStringSelection())
+            conf[attr] = int(wids[attr].GetStringSelection())
 
         for attr in ('fft_kwindow', 'fft_rwindow', 'plotone_op',
                      'plotsel_op', 'plotalt_op'):
-            form_opts[attr] = wids[attr].GetStringSelection()
+            conf[attr] = wids[attr].GetStringSelection()
         time.sleep(0.001)
-        conf = self.get_config()
-        conf.update(form_opts)
         self.skip_process = skip_save
-        return form_opts
+        if as_copy:
+            conf = copy.deepcopy(conf)
+        if dgroup is not None:
+            setattr(dgroup, self.configname, conf)            
+        return conf
 
 
     def onSaveConfigBtn(self, evt=None):
-        self.read_form()
-        self.set_defaultconfig(conf)
+        self.set_defaultconfig(self.read_form())
 
     def onCopyParam(self, name=None, evt=None):
-
-        self.read_form()
-        conf = self.get_config()
+        conf = self.read_form()
         opts = {}
         def copy_attrs(*args):
             return {a: conf[a] for a in args}
-
         name = str(name)
         if name in ('e0', 'rbkg', 'bkg_kweight', 'fft_kweight'):
             opts = copy_attrs(name)
@@ -456,6 +463,7 @@ class EXAFSPanel(TaskPanel):
             if grp != self.controller.group and not grp.is_frozen:
                 self.update_config(opts, dgroup=grp)
 
+
     def _set_frozen(self, frozen):
         try:
             dgroup = self.controller.get_group()
@@ -479,27 +487,20 @@ class EXAFSPanel(TaskPanel):
 
     def onProcess(self, event=None):
         """ handle process events"""
-        if self.skip_process:
-            time.sleep(0.25)
-            self.skip_process = False
+        if self.skip_process or ((time.time() - self.last_process_time) < 0.5):
             return
+        self.last_process_time = time.time()
         self.skip_process = True
-        self.read_form()
         self.process(dgroup=self.dgroup)
         self.skip_process = False
-
-        plotter = self.onPlotOne
-        if self.last_plot == 'selected':
-            plotter = self.onPlotSel
-        wx.CallAfter(partial(plotter))
+        plotter = self.onPlotSel if self.last_plot=='selected' else self.onPlotOne
+        plotter()
 
     def process(self, dgroup=None, **kws):
         if dgroup is not None:
             self.dgroup = dgroup
 
-        conf = self.get_config(self.dgroup)
-        conf['group'] = self.dgroup.groupname
-        conf.update(self.read_form())
+        conf = self.read_form()
         conf.update(kws)
         if not 'fft_kwindow' in conf:
             return
@@ -544,29 +545,27 @@ class EXAFSPanel(TaskPanel):
     def onPlotOne(self, evt=None, dgroup=None):
         if self.skip_plotting:
             return
-        form = self.read_form()
-        if len(form) == 0:
-            return
+        conf = self.read_form(as_copy=True)
         if dgroup is not None:
             self.dgroup = dgroup
-            form['group'] = dgroup.groupname
+            conf['group'] = dgroup.groupname
         self.process(dgroup=self.dgroup)
-        form['title'] = '"%s"' % self.dgroup.filename
+        conf['title'] = '"%s"' % self.dgroup.filename
 
-        cmd = PlotCmds[form['plotone_op']] + ", win=1, title={title:s})"
+        cmd = PlotCmds[conf['plotone_op']] + ", win=1, title={title:s})"
         # 2nd plot
-        cmd2 =  PlotCmds[form['plotalt_op']]
+        cmd2 =  PlotCmds[conf['plotalt_op']]
         if cmd2 is not None:
             cmd2 = cmd2.replace('plot_kweight', 'plot_kweight_alt')
             cmd2 = cmd2 + ", win=2, title={title:s})"
             cmd = "%s\n%s" % (cmd, cmd2)
             self.controller.get_display(win=2)
 
-        self.larch_eval(cmd.format(**form))
+        self.larch_eval(cmd.format(**conf))
         self.last_plot = 'one'
         self.parent.SetFocus()
-        if evt is not None:
-            evt.Skip()
+        # if evt is not None:
+        #     evt.Skip()
 
     def onPlotSel(self, evt=None):
         if self.skip_plotting:
@@ -575,27 +574,27 @@ class EXAFSPanel(TaskPanel):
         if len(group_ids) < 1:
             return
 
-        form = self.read_form()
-        bcmd = PlotCmds[form['plotsel_op']]
-        form['new'] = 'True'
-        offset = form['plot_voffset']
+        conf = self.read_form(as_copy=True)
+        bcmd = PlotCmds[conf['plotsel_op']]
+        conf['new'] = 'True'
+        offset = conf['plot_voffset']
         for i, checked in enumerate(group_ids):
             groupname = self.controller.file_groups[str(checked)]
             dgroup = self.controller.get_group(groupname)
             if dgroup is not None:
-                form['group'] = dgroup.groupname
-                form['label'] = dgroup.filename
-                form['offset'] = offset * i
+                conf['group'] = dgroup.groupname
+                conf['label'] = dgroup.filename
+                conf['offset'] = offset * i
                 self.process(dgroup=dgroup)
 
                 extra = """, offset={offset:.3f}, win=1, delay_draw=True,
     label='{label:s}', new={new:s})"""
                 cmd = "%s%s" % (bcmd, extra)
-                self.larch_eval(cmd.format(**form))
-                form['new'] = 'False'
+                self.larch_eval(cmd.format(**conf))
+                conf['new'] = 'False'
 
         self.larch_eval("redraw(win=1, show_legend=True)")
         self.last_plot = 'selected'
         self.parent.SetFocus()
-        if evt is not None:
-            evt.Skip()
+        # if evt is not None:
+        #    evt.Skip()
