@@ -35,12 +35,10 @@ from larch.wxlib import (LarchFrame, ColumnDataFileFrame, AthenaImporter,
                          SetTip, get_icon, SimpleText, pack, Button, Popup,
                          HLine, FileSave, Choice, Check, MenuItem,
                          GUIColors, CEN, LEFT, FRAMESTYLE, Font, FONTSIZE,
-                         flatnotebook, LarchUpdaterDialog)
-
-from larch.wxlib.plotter import _newplot, _plot, last_cursor_pos
+                         flatnotebook, LarchUpdaterDialog,
+                         CIFFrame, FeffResultsFrame)
 
 from larch.fitting import fit_report
-from larch.utils import group2dict
 from larch.site_config import icondir
 
 from .prepeak_panel import PrePeakPanel
@@ -48,6 +46,7 @@ from .xasnorm_panel import XASNormPanel
 from .lincombo_panel import LinearComboPanel
 from .pca_panel import PCAPanel
 from .exafs_panel import EXAFSPanel
+from .feffit_panel import FeffitPanel
 from .regress_panel import RegressionPanel
 from .xas_controller import XASController
 
@@ -68,7 +67,7 @@ CEN |=  wx.ALL
 FILE_WILDCARDS = "Data Files(*.0*,*.dat,*.xdi,*.prj,*.spc,*.hdf5)|*.0*;*.dat;*.DAT;*.xdi;*.prj;*.sp*c;*.h*5|All files (*.*)|*.*"
 
 ICON_FILE = 'onecone.ico'
-XASVIEW_SIZE = (950, 750)
+XASVIEW_SIZE = (990, 750)
 PLOTWIN_SIZE = (550, 550)
 
 NB_PANELS = {'Normalization': XASNormPanel,
@@ -76,7 +75,8 @@ NB_PANELS = {'Normalization': XASNormPanel,
              'PCA':  PCAPanel,
              'Linear Combo': LinearComboPanel,
              'Regression': RegressionPanel,
-             'EXAFS':  EXAFSPanel}
+             'EXAFS':  EXAFSPanel,
+             'Feff Fitting': FeffitPanel}
 
 QUIT_MESSAGE = '''Really Quit? You may want to save your project before quitting.
  This is not done automatically!'''
@@ -115,15 +115,14 @@ class XASFrame(wx.Frame):
         self.last_array_sel_col = {}
         self.last_array_sel_spec = {}
         self.paths2read = []
+        self.current_filename = filename        
 
         title = "Larch XAS GUI: XAS Visualization and Analysis"
 
         self.larch_buffer = parent
         if not isinstance(parent, LarchFrame):
-            self.larch_buffer = LarchFrame(_larch=_larch, is_standalone=False)
+            self.larch_buffer = LarchFrame(_larch=_larch, is_standalone=False, with_raise=False)
 
-        self.larch_buffer.Show()
-        self.larch_buffer.Raise()
         self.larch = self.larch_buffer.larchshell
         self.larch.symtable._sys.xas_viewer = Group()
 
@@ -137,21 +136,30 @@ class XASFrame(wx.Frame):
         self.SetSize(XASVIEW_SIZE)
 
         self.SetFont(Font(FONTSIZE))
-        self.larch_buffer.Hide()
         self.createMainPanel()
         self.createMenus()
         self.statusbar = self.CreateStatusBar(2, style=wx.STB_DEFAULT_STYLE)
         self.statusbar.SetStatusWidths([-3, -1])
-        statusbar_fields = [" ", "initializing...."]
+        statusbar_fields = [" ", "ready"]
         for i in range(len(statusbar_fields)):
             self.statusbar.SetStatusText(statusbar_fields[i], i)
-            self.current_filename = filename
         self.Show()
         if version_info is not None:
             if version_info.update_available:
                 self.onCheckforUpdates()
-        if filename is not None:
-            wx.CallAfter(self.onRead, filename)
+
+        self.controller.init_larch()
+        plotframe = self.controller.get_display(stacked=False)
+        xpos, ypos = self.GetPosition()
+        xsiz, ysiz = self.GetSize()
+        plotframe.SetPosition((xpos+xsiz+5, ypos))
+        plotframe.SetSize((600, 650))
+
+        self.Raise()        
+        self.statusbar.SetStatusText('ready', 1)
+        if self.current_filename is not None:
+            wx.CallAfter(self.onRead, self.current_filename)        
+
 
     def createMainPanel(self):
         display0 = wx.Display(0)
@@ -193,7 +201,7 @@ class XASFrame(wx.Frame):
         panel = wx.Panel(splitter)
         sizer = wx.BoxSizer(wx.VERTICAL)
 
-        self.title = SimpleText(panel, 'initializing...', size=(300, -1))
+        self.title = SimpleText(panel, ' ', size=(300, -1))
         self.title.SetFont(Font(FONTSIZE+2))
 
         ir = 0
@@ -206,20 +214,25 @@ class XASFrame(wx.Frame):
         pack(panel, sizer)
 
         splitter.SplitVertically(leftpanel, panel, 1)
-        wx.CallAfter(self.init_larch)
+
 
     def process_normalization(self, dgroup):
-        self.get_nbpage('xasnorm').process(dgroup, noskip=True)
+        self.get_nbpage('xasnorm')[1].process(dgroup, noskip=True)
+
+    def process_exafs(self, dgroup):
+        self.get_nbpage('exafs')[1].process(dgroup)
 
     def get_nbpage(self, name):
         "get nb page by name"
         name = name.lower()
-        for page in self.nb.pagelist:
+        out = (1, self.nb.GetCurrentPage())
+        for i, page in enumerate(self.nb.pagelist):
             if name in page.__class__.__name__.lower():
-                return page
+                out = (i, page)
+        return out
 
     def onNBChanged(self, event=None):
-        is_prepeak = self.nb.GetCurrentPage() is self.get_nbpage('prepeak')
+        is_prepeak = self.nb.GetCurrentPage() is self.get_nbpage('prepeak')[1]
         for imenu, menudat in enumerate(self.menubar.GetMenus()):
             if 'pre-edge' in menudat[1].lower():
                 self.menubar.EnableTop(imenu, is_prepeak)
@@ -234,21 +247,9 @@ class XASFrame(wx.Frame):
     def onSelNone(self, event=None):
         self.controller.filelist.select_none()
 
-    def init_larch(self):
-        self.SetStatusText('initializing Larch', 1)
-        self.title.SetLabel('')
-
+    def init_larch(self, filename=None):
         self.controller.init_larch()
 
-        plotframe = self.controller.get_display(stacked=False)
-        xpos, ypos = self.GetPosition()
-        xsiz, ysiz = self.GetSize()
-        plotframe.SetPosition((xpos+xsiz+5, ypos))
-        plotframe.SetSize((600, 650))
-
-        self.SetStatusText('ready', 1)
-        self.Raise()
-
     def write_message(self, msg, panel=0):
         """write a message to the Status Bar"""
         self.statusbar.SetStatusText(msg, panel)
@@ -298,6 +299,7 @@ class XASFrame(wx.Frame):
         fmenu = wx.Menu()
         group_menu = wx.Menu()
         data_menu = wx.Menu()
+        feff_menu = wx.Menu()
         ppeak_menu = wx.Menu()
         m = {}
 
@@ -386,6 +388,14 @@ class XASFrame(wx.Frame):
         self.menubar.Append(data_menu, "Data")
         self.menubar.Append(ppeak_menu, "Pre-edge Peaks")
 
+
+        MenuItem(self, feff_menu, "Browse CIF Structures, Run Feff",
+                 "Browse CIF Structure, run Feff", self.onCIFBrowse)
+        MenuItem(self, feff_menu, "Browse Feff Calculations",
+                 "Browse Feff Calculations, Get Feff Paths", self.onFeffBrowse)
+
+        self.menubar.Append(feff_menu, "Feff")
+
         hmenu = wx.Menu()
         MenuItem(self, hmenu, 'About XAS Viewer', 'About XAS Viewer',
                  self.onAbout)
@@ -668,14 +678,30 @@ class XASFrame(wx.Frame):
             except Exception:
                 pass
 
-        for name, wid in self.subframes.items():
+        def destroy(wid):
             if hasattr(wid, 'Destroy'):
                 try:
                     wid.Destroy()
                 except Exception:
                     pass
-        time.sleep(0.05)
+                time.sleep(0.01)
+            
+        for name, wid in self.subframes.items():
+            destroy(wid)
 
+        for i in range(self.nb.GetPageCount()):
+            nbpage = self.nb.GetPage(i)
+            timers = getattr(nbpage, 'timers')
+            for t in timers.values():
+                t.Stop()
+            
+            if hasattr(nbpage, 'subframes'):
+                for name, wid in nbpage.subframes.items():
+                    destroy(wid)
+
+                    
+                
+        time.sleep(0.05)
         self.Destroy()
 
     def show_subframe(self, name, frameclass, **opts):
@@ -698,6 +724,13 @@ class XASFrame(wx.Frame):
                            read_ok_cb=partial(self.onRead_OK,
                                               overwrite=True))
 
+    def onCIFBrowse(self, event=None):
+        self.show_subframe('cif_feff', CIFFrame, _larch=self.larch)
+
+    def onFeffBrowse(self, event=None):
+        self.show_subframe('feff_paths', FeffResultsFrame,
+                           xasmain=self, _larch=self.larch)
+
     def onLoadFitResult(self, event=None):
         pass
         # print("onLoadFitResult??")
@@ -934,3 +967,15 @@ class XASViewer(wx.App, wx.lib.mixins.inspection.InspectionMixin):
 
 def xas_viewer(**kws):
     XASViewer(**kws)
+
+
+if __name__ == "__main__":
+    import argparse
+    parser = argparse.ArgumentParser(description="Larch XAS GUI")
+    parser.add_argument(
+        '-f', '--filename',
+        dest='filename',
+        help='data file to load')
+    args = parser.parse_args()
+    app = XASViewer(**vars(args))
+    app.MainLoop()
