@@ -23,6 +23,7 @@ And the answers are that there are simple methods for:
 """
 
 import os
+import re
 import time
 import json
 from base64 import b64encode, b64decode
@@ -47,7 +48,7 @@ from xraydb.chemparser import chemparse
 from .amscifdb_utils import (make_engine, isAMSCIFDB, create_amscifdb,
                              put_optarray, get_optarray)
 from .xrd_cif import XRDCIF, elem_symbol
-from .cif2feff import cif2feff6l
+from .cif2feff import cif2feffinp
 
 from ..site_config import user_larchdir
 from .. import logger
@@ -229,7 +230,7 @@ class CifStructure():
                                          energy=energy, qmin=qmin,
                                          qmax=qmax)
 
-    def get_feff6inp(self, absorber, edge=None, cluster_size=8.0, absorber_site=1):
+    def get_feffinp(self, absorber, edge=None, cluster_size=8.0, absorber_site=1, version8=True):
         pub = self.publication
         journal = f"{pub.journalname} {pub.volume}, pp. {pub.page_first}-{pub.page_last} ({pub.year:d})"
         authors = ', '.join(pub.authors)
@@ -237,21 +238,22 @@ class CifStructure():
                   f'Mineral Name: {self.mineral.name:s}']
 
         if not self.formula_title.startswith('<missing'):
-            titles.appen(f'Formula Title: {self.formula_title}')
+            titles.append(f'Formula Title: {self.formula_title}')
 
         titles.extend([f'Journal: {journal}', f'Authors: {authors}'])
         if not self.pub_title.startswith('<missing'):
             for i, line in enumerate(self.pub_title.split('\n')):
                 titles.append(f'Title{i+1:d}: {line}')
 
-        return cif2feff6l(self.ciftext, absorber, edge=edge,
-                          cluster_size=cluster_size,
-                          absorber_site=absorber_site, extra_titles=titles)
+        return cif2feffinp(self.ciftext, absorber, edge=edge,
+                           cluster_size=cluster_size,
+                           absorber_site=absorber_site,
+                           extra_titles=titles, version8=version8)
 
-    def save_feff6inp(self, absorber, edge=None, cluster_size=8.0, absorber_site=1,
-                      filename=None):
-        feff6text = self.get_feff6inp(absorber, edge=edge, cluster_size=cluster_size,
-                                      absorber_site=absorber_site)
+    def save_feffinp(self, absorber, edge=None, cluster_size=8.0, absorber_site=1,
+                      filename=None, version8=True):
+        feff6text = self.get_feffinp(absorber, edge=edge, cluster_size=cluster_size,
+                                      absorber_site=absorber_site, version8=version8)
         if filename is None:
             min_name = self.mineral.name.lower()
             if min_name in ('', '<missing>', 'None'):
@@ -481,17 +483,24 @@ class AMSCIFDB():
         return self.get_cif(cif_id)
 
 
-    def add_ciffile(self, filename, url=''):
+    def add_ciffile(self, filename, cif_id=None, url=''):
         if not HAS_CIFPARSER:
             raise ValueError("CifParser from pymatgen not available. Try 'pip install pymatgen'.")
         cif = CifParser(filename)
-        dat = cif._cif.data['global'].data
+        cifkey = list(cif._cif.data.keys())[0]
+        dat = cif._cif.data[cifkey].data
         formula = dat['_chemical_formula_sum']
         compound  = dat.get('_chemical_compound_source', '<missing>')
 
         # get spacegroup and symmetry
         sgroup_name = dat['_symmetry_space_group_name_H-M']
-        symm_xyz = json.dumps(dat['_space_group_symop_operation_xyz'])
+        symm_xyz = dat.get('_space_group_symop_operation_xyz', None)
+        if symm_xyz is None:
+            symm_xyz = dat.get('_symmetry_equiv_pos_as_xyz', None)
+        if symm_xyz is None:
+            raise ValueError(f'Cannot read symmetries from file {filename:s}')
+
+        symm_xyz = json.dumps(symm_xyz)
 
         sgroup = self.get_spacegroup(sgroup_name)
         if sgroup is not None and sgroup.symmetry_xyz != symm_xyz:
@@ -523,8 +532,29 @@ class AMSCIFDB():
         else:
             pub = pubs[0]
 
+        density = dat.get('_exptl_crystal_density_meas', None)
+        if density is None:
+            density = dat.get('_exptl_crystal_density_diffrn', None)
+
+        if cif_id is None:
+            cif_id = dat.get('_database_code_amcsd', None)
+            if cif_id is None:
+                cif_id = dat.get('_cod_database_code', None)
+            if cif_id is None:
+                cif_id = self.next_cif_id()
+        cif_id = int(cif_id)
+
+        # check again for this cif id (must match CIF AMS id and formula
+        tabcif = self.tables['cif']
+        this = select(tabcif.c.id, tabcif.c.formula).where(tabcif.c.id==int(cif_id)).execute().fetchone()
+        if this is not None:
+            _cid, _formula = this
+            if formula.replace(' ', '') == _formula.replace(' ', ''):
+                return cif_id
+            else:
+                cif_id = self.next_cif_id()
+
 
-        cif_id = int(dat['_database_code_amcsd'])
         self.add_cifdata(cif_id, mineral.id, pub.id, sgroup.id,
                          formula=formula, compound=compound,
                          formula_title=dat.get('_amcsd_formula_title', '<missing>'),
@@ -549,9 +579,9 @@ class AMSCIFDB():
                          beta=dat['_cell_angle_beta'],
                          gamma=dat['_cell_angle_gamma'],
                          cell_volume=dat['_cell_volume'],
-                         crystal_density=dat['_exptl_crystal_density_diffrn'],
+                         crystal_density=density,
                          url=url)
-
+        return cif_id
 
     def get_cif(self, cif_id, as_strings=False):
         """get Cif Structure object """
@@ -583,15 +613,15 @@ class AMSCIFDB():
                      'cell_volume', 'crystal_density'):
             val = getattr(cif, attr, '-1')
             if not as_strings:
-                try:
-                    val = float(val)
-                except:
+                if val is not None:
+                    if '(' in val:
+                        val = val.split('(')[0]
                     if ',' in val and '.' not in val:
                         val = val.replace(',', '.')
-                        try:
-                            val = float(val)
-                        except:
-                            pass
+                    try:
+                        val = float(val)
+                    except:
+                        pass
             setattr(out, attr, val)
 
         for attr in ('atoms_sites', 'atoms_aniso_label'):
@@ -619,6 +649,16 @@ class AMSCIFDB():
         return out
 
 
+    def next_cif_id(self):
+        """next available CIF ID > 200000 that is not in current table"""
+        max_id = 200_000
+        tabcif = self.tables['cif']
+        for row in select(tabcif.c.id).where(tabcif.c.id>200000).execute().fetchall():
+            if row[0] > max_id:
+                max_id = row[0]
+        return max_id + 1
+
+
     def all_minerals(self):
         names = []
         for row in self.tables['minerals'].select().execute().fetchall():
@@ -655,7 +695,8 @@ class AMSCIFDB():
 
     def find_cifs(self, id=None, mineral_name=None, author_name=None,
                   journal_name=None, contains_elements=None,
-                  excludes_elements=None, strict_contains=False, full_occupancy=False):
+                  excludes_elements=None, strict_contains=False,
+                  full_occupancy=False, max_matches=1000):
         """return list of CIF Structures matching mineral, publication, or elements
         """
         if id is not None:
@@ -670,29 +711,57 @@ class AMSCIFDB():
         tab_ap = self.tables['publication_authors']
         tab_ce = self.tables['cif_elements']
 
-        args = []
-        if mineral_name is not None:
-            args.append(func.lower(tabmin.c.name)==mineral_name.lower())
-            args.append(tabmin.c.id==tabcif.c.mineral_id)
+        matches = []
+        t0 = time.time()
+        if mineral_name is None:
+            mineral_name = ''
+        mineral_name = mineral_name.strip()
+            
+        if mineral_name not in (None, '') and ('*' in mineral_name or
+                                               '^' in mineral_name or
+                                               '$' in mineral_name):
+            pattern = mineral_name.replace('*', '.*').replace('..*', '.*')
+            matches = []
+            for row in self.tables['minerals'].select().execute().fetchall():
+                if re.search(pattern, row.name, flags=re.IGNORECASE) is not None:
+                    query = select(tabcif.c.id).where(tabcif.c.mineral_id==row.id)
+                    for m in [row[0] for row in query.execute().fetchall()]:
+                        if m not in matches:
+                           matches.append(m)
 
-        if journal_name is not None:
-            args.append(func.lower(tabpub.c.journalname)==journal_name.lower())
-            args.append(tabpub.c.id==tabcif.c.publication_id)
-
-        if author_name is not None:
-            args.append(func.lower(tabaut.c.name)==author_name.lower())
-            args.append(tabcif.c.publication_id==tab_ap.c.publication_id)
-            args.append(tabaut.c.id==tab_ap.c.author_id)
+            if journal_name not in (None, ''):
+                pattern = journal_name.replace('*', '.*').replace('..*', '.*')
+                new_matches = []
+                for c in matches:
+                    pub_id = select(tabcif.c.publication_id).where(tabcif.c.id==c).execute().fetchone()[0]
+                    this_journal = select(tabpub.c.journalname).where(tabpub.c.id==pub_id).execute().fetchone()[0]
+                    if re.search(pattern,  this_journal, flags=re.IGNORECASE) is not None:
+                        new_matches.append[c]
+                matches = new_matches
 
 
-        query = select(tabcif.c.id)
-        if len(args) > 0:
-            query = select(tabcif.c.id).where(and_(*args))
-        matches = [row[0] for row in self.conn.execute(query).fetchall()]
-        matches = list(set(matches))
+        else: # strict mineral name or no mineral name
+            args = []
+            if mineral_name not in (None, ''):
+                args.append(func.lower(tabmin.c.name)==mineral_name.lower())
+                args.append(tabmin.c.id==tabcif.c.mineral_id)
+
+            if journal_name not in (None, ''):
+                args.append(func.lower(tabpub.c.journalname)==journal_name.lower())
+                args.append(tabpub.c.id==tabcif.c.publication_id)
+
+            if author_name not in (None, ''):
+                args.append(func.lower(tabaut.c.name)==author_name.lower())
+                args.append(tabcif.c.publication_id==tab_ap.c.publication_id)
+                args.append(tabaut.c.id==tab_ap.c.author_id)
+
+            query = select(tabcif.c.id)
+            if len(args) > 0:
+                query = select(tabcif.c.id).where(and_(*args))
+            matches = [row[0] for row in self.conn.execute(query).fetchall()]
+            matches = list(set(matches))
         #
         cif_elems = self.get_cif_elems()
-
         if contains_elements is not None:
             for el in contains_elements:
                 new_matches = []
@@ -701,11 +770,11 @@ class AMSCIFDB():
                         new_matches.append(row)
                 matches = new_matches
 
-            if excludes_elements is None and strict_contains:
+            if strict_contains:
                 excludes_elements = elem_symbol[:]
                 for c in contains_elements:
-                    excludes_elements.remove(c)
-
+                    if c in excludes_elements:
+                        excludes_elements.remove(c)
         if excludes_elements is not None:
             bad = []
             for el in excludes_elements:
@@ -724,11 +793,16 @@ class AMSCIFDB():
                 if occ in ('0', 0, None):
                     good.append(cif_id)
                 else:
-                    min_wt = min([float(x) for x in occ])
+                    try:
+                        min_wt = min([float(x) for x in occ])
+                    except:
+                        min_wt = 0                            
                     if min_wt > 0.96:
                         good.append(cif_id)
             matches = good
 
+        if len(matches) > max_matches:
+            matches = matches[:max_matches]
         return [self.get_cif(cid) for cid in matches]
 
 
